#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_LIBSM
#undef PACKAGE
#undef VERSION
#undef ENABLE_THREADS
#undef SENDMAIL_PATH
#undef SYSTEM_MAIL_DIR
#undef HAVE_LDAP
#undef HAVE_TIMEZONE
#undef HAVE_ALTZONE
#undef HAVE_TM_GMTOFF
#undef HAVE_KRB4
#undef NEED_KRB_SENDAUTH_PROTO
#undef HAVE_HEIMDAL_KRB5
#undef HAVE_MIT_KRB5
#undef HAVE_KRB5
#undef HAVE_NSS
#undef HAVE_OPENSSL
#undef HAVE_SSL
#undef USE_DOT
#undef USE_FCNTL
#undef USE_FLOCK
#undef ENABLE_NNTP
#undef ENABLE_IPv6
#undef HAVE_BROKEN_SPOOL
#undef ENABLE_PEDANTIC_PGPMIME
#undef HAVE_KDE_APPLNK

/* db3 version */
#undef EVOLUTION_DB_VERSION_MAJOR
#undef EVOLUTION_DB_VERSION_MINOR
#undef EVOLUTION_DB_VERSION_PATCH

/* Sub-version identification string.  */
#undef SUB_VERSION

/* Preview-release string */
#undef VERSION_COMMENT

/* Define if ctime_r takes three arguments */
#undef CTIME_R_THREE_ARGS

/* Define if gethostbyname_r takes five arguments */
#undef GETHOSTBYNAME_R_FIVE_ARGS

/* Define if gethostbyaddr_r takes seven arguments */
#undef GETHOSTBYADDR_R_SEVEN_ARGS

/* Define to `int' if your system doesn't have `socklen_t'. */
#undef socklen_t

/* Define to the path to a program to kill processes given the name
   (eg. "killall" or "killp").  */
#undef KILL_PROCESS_CMD
